llarrma <-
function(ped, penalty=c("lasso","rand.lasso"), method.lambda="perm", subsamples=NULL, proportion=1/2, num.resamples=1000, family=c("gaussian","binomial"), min.lambda=.001,ped.get.predictors=ped.get.genotypes.012, subsample.method="proportional", rand.alpha=0.7, rand.wtype="flip" )
{
	if(1!=length(family) )
   	{
		stop("Only one family may be specified \n")
	}
   	if (1!=length(penalty))
   	{
		stop("only one of lasso/rand.lasso can be run at a time \n")
   	}
	if(1!=length(method.lambda))
	{
		stop("Only one method for lambda selection can be specified \n")
	}
   	retval<-NULL
	retval$resample<-"subsamples"
   	retval$penalty<-switch(penalty, "lasso"="LASSO", "rand.lasso"=paste("Randomized LASSO with alpha = ", rand.alpha, sep=""))
	retval$family<-family
	retval$method.lambda<-switch(method.lambda, "perm"= "Permutation Selection", "comp.dev"="Complement Deviance Selection")
	retval$ped.predictor<-deparse(substitute(ped.get.predictors))
	retval$num.resamples<-num.resamples 

   	if( is.list(ped) )
   	{
		retval$inc.mat<-matrix(0,nrow=ncol(ped.get.predictors(ped[[1]])),ncol=num.resamples)
		retval$lambdas<-NULL
		retval$predictors<-ped.get.markers(ped[[1]])
		retval$num.subjects<-ped.get.num.subjects(ped[[1]])
		retval$num.predictors<-ped.get.num.markers(ped[[1]])
	}
   	else
   	{
     	retval$inc.mat<-matrix(0,nrow=ncol(ped.get.predictors(ped)),ncol=num.resamples)
		retval$lambdas<-NULL
		retval$predictors<-ped.get.markers(ped)
		retval$num.subjects<-ped.get.num.subjects(ped)
		retval$num.predictors<-ped.get.num.markers(ped)
 	}
   if(is.null(subsamples))
   {
     	subsamples<-subsamples.llarrma(ped, proportion=proportion, num.subsamples=num.resamples, family=family,subsample.type=subsample.method,ped.get.predictors=ped.get.predictors)
   }
   if(penalty=="lasso")
   {
		if("comp.dev"==method.lambda)   
      	{
			for(i in 1:num.resamples)
      		{
				if (i %% 10 == 0) cat(sep="", "[",i,"]")
            	sample<-subsample.select(ped, indicies=subsamples, iteration=i, ped.get.predictors=ped.get.predictors)
            	model<- glmnet(sample$sub.data, sample$sub.response, family=family, alpha=1, standardize = F)

				predmat.response<-predict(model, sample$comp.data, type = "response")
				cvm.response<-comp.error(sample$comp.response, predmat.response, type = family)
				retval$inc.mat[,i]<-model$beta[,which.min(cvm.response)]
				retval$lambdas[i]<-retval$lambdas[which.min(cvm.response)]
        	}
		}
		if("perm"==method.lambda)
		{
			for(i in 1:num.resamples)
			{
				if (i %% 10 == 0) cat(sep="", "[",i,"]")
				samp<-subsample.select(ped, indicies=subsamples, iteration=i,ped.get.predictors=ped.get.predictors)
				retval$lambdas[i]<-get.max.lambda.perm(samp, n.perm=20, type="median", penalty="lasso", family=family)
				model.perm<-glmnet(samp$sub.data, samp$sub.response, family=family, lambda=retval$lambdas[i], alpha=1, standardize = F)
				retval$inc.mat[,i]<-model.perm$beta[,1]
		   	}
		}
	}
   	if(penalty=="rand.lasso")
   	{
	retval$rand.lasso.weights<-matrix(NA, nrow=ped.get.num.markers(ped), ncol=num.resamples)
	retval$rand.wtype=rand.wtype
		if("comp.dev"==method.lambda)   
      	{
        	for(i in 1:num.resamples)
        	{
				if (i %% 10 == 0) cat(sep="", "[",i,"]")
				sample<-subsample.select(ped, indicies=subsamples, iteration=i, randomized=TRUE,ped.get.predictors=ped.get.predictors, rand.alpha=rand.alpha, wtype=rand.wtype)
				retval$rand.lasso.weights[,i]=sample$rand.weight
				model<- glmnet(sample$sub.rand, sample$sub.response, family=family, alpha=1, standardize = F)

				predmat.response<-predict(model, sample$comp.rand, type = "response")
				cvm.response<-comp.error(sample$comp.response, predmat.response, type = family)
				retval$inc.mat[,i]<-model$beta[,which.min(cvm.response)]
				retval$lambdas[i]<-retval$lambdas[which.min(cvm.response)]
        	}
		}
      	if("perm" == method.lambda)
		{
			for(i in 1:num.resamples)
			{
				if (i %% 10 == 0) cat(sep="", "[",i,"]")
				samp<-subsample.select(ped, indicies=subsamples, iteration=i, randomized=T, rand.alpha=rand.alpha, wtype=rand.wtype, ped.get.predictors=ped.get.predictors)
				retval$rand.lasso.weights[,i]=samp$rand.weight
				retval$lambdas[i]<-get.max.lambda.perm(samp, n.perm=20, type="median", penalty="rand.lasso", rand.alpha=rand.alpha, family=family)
				model.perm<-glmnet(samp$sub.rand, samp$sub.response, family=family, lambda=retval$lambdas[i], alpha=1, standardize = F)        			
				retval$inc.mat[,i]<-model.perm$beta[,1]
			}
		}
  	}
	class(retval)<-"FReMA"
	retval  
}
