\name{FReMA}
\alias{FReMA}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
  Fractional-resample Model Averaging
}
\description{
Implementation of FReMA (Fractional-resample Model Averaging) for analysis of GWAS hit regions with a general model capable of capturing both additive and dominance SNP effects. Options exist for the use of standard or randomized penalties, dominance and additive grouped model or additive model, and subsampling or fractional weighting.
}
\usage{
FReMA(ped, num.resamples = 100, family = "gaussian", penalty = "standard", model = "dom", resample = "fractional", resample.mat = NULL, rand.alpha = 0.7)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{ped}{ A "ped" class object, See \code{\link{read.ped}}
}
  \item{num.resamples}{
number of resamples to run
}
  \item{family}{
family for model fit. default is "gaussian", but other GLM options are available
}
  \item{penalty}{
type of penalty to use, default "standard". Option of "randomized" available
}
  \item{model}{
Model of SNP effects to assume. default is "dom" for additive and dominance effects under grouped penalization. "additive" only model also available.
}
  \item{resample}{
resampling method, default "fractional". Option for "subsampling" available if model is "additive"
}
  \item{resample.mat}{
optional resample matrix to specify specific resamples to run.
}
  \item{rand.alpha}{
randomization parameter when penalty ="randomized"
}
}
\details{
%%  ~~ If necessary, more details than the description above ~~
}
\value{
basically a list of components of the FreMA class: 
\item{penalty}{the penalty used}
\item{family}{the model family used}
\item{method.lambda}{the local lambda selection method}
\item{num.resamples}{number of resamples used}
\item{inc.mat}{matrix of coefficient values, each column coincides with a resample}
\item{predictors}{vector of the predictor names}
\item{num.subjects}{the number of subjects used}
\item{num.predictors}{the number of predictors evaluated}
\item{lambdas}{vector of the locally selected lambda value for each resamplesample}
}
\references{
%% ~put references to the literature/web site here ~
}
\author{
%%  ~~who you are~~
}
\note{
%%  ~~further notes~~
}

%% ~Make other sections like Warning with \section{Warning }{....} ~

\seealso{
%% ~~objects to See Also as \code{\link{help}}, ~~~
}
\examples{
data("FReMA")  #contains a ped object named "ped"
output<-FReMA(ped, num.resamples=20, family="binomial") #runs FreMA on the example data
output.rand<-FReMA(ped, num.resamples=20, penalty="randomized", family="binomial") #runs FreMA with randomized group LASSO on the example data
output.additive<-FReMA(ped, num.resamples=20, model="additive") #runs FreMA with an additive only model assumed
output
summary(output)
FReMIPs<-summary(output, return.FReMIP=TRUE) #prints summary and also returns the vector of FReMIPs
plot(output) #basic plot for the output 
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
